
[![Build Status](https://travis-ci.com/hasii2011/PyUt.svg?branch=master)](https://travis-ci.com/hasii2011/PyUt)
[![Maintenance](https://img.shields.io/badge/Maintained%3F-yes-green.svg)](https://GitHub.com/Naereen/StrapDown.js/graphs/commit-activity)
[![macOS](https://svgshare.com/i/ZjP.svg)](https://svgshare.com/i/ZjP.svg)
<img width="34" height="17" src="./src/org/pyut/resources/img/gplv3-with-text-136x68.png"/> 

[![forthebadge made-with-python](http://ForTheBadge.com/images/badges/made-with-python.svg)](https://www.python.org/)

𝓟 𝓨 𝓤 𝓣 stands for Python UML Tool. This is the external graphical shapes module for Pyut
that allows for external plugin development;

This project depends on pyutmodel and wxPython
